==> v0.13.11.tar.gz: git-next/crates/cli/src/repo/tests/handlers/advance_next.rs <==
use std::time::Duration;

use crate::repo::messages::AdvanceNextPayload;

//
use super::*;

#[test_log::test(actix::test)]
async fn should_fetch_then_push_then_revalidate() -> TestResult {
    //given
    let fs = given::a_filesystem();
    let (mut open_repository, repo_details) = given::an_open_repository(&fs);
    let next_commit = given::a_commit_with_message("feat: next".to_string());
    let dev_commit_history = vec![
        given::a_commit_with_message("feat: dev".to_string()),
        given::a_commit_with_message("feat: target".to_string()),
        next_commit.clone(),
    ];

    let mut seq = mockall::Sequence::new();
    open_repository
        .expect_fetch()
        .times(1)
        .in_sequence(&mut seq)
        .return_once(|| Ok(()));
    open_repository
        .expect_push()
        .times(1)
        .in_sequence(&mut seq)
        .return_once(|_, _, _, _| Ok(()));
    open_repository
        .expect_fetch()
        .times(1)
        .in_sequence(&mut seq)
        .return_once(|| Ok(()));

    //when
    let (addr, log) = when::start_actor_with_open_repository(
        Box::new(open_repository),
        repo_details,
        given::a_forge(),
    );
    addr.send(crate::repo::messages::AdvanceNext::new(
        AdvanceNextPayload {
            next: next_commit.clone(),
            main: next_commit.clone(),
            dev_commit_history,
        },
    ))
    .await?;
    actix_rt::time::sleep(Duration::from_millis(9)).await;
    System::current().stop();

    //then
    tracing::debug!(?log, "");
    log.require_message_containing("send: ValidateRepo")?;
    Ok(())
}

==> v0.14.1.tar.gz: git-next/crates/cli/src/repo/tests/handlers/advance_next.rs <==
use std::time::Duration;

use crate::{
    repo::messages::{AdvanceNext, AdvanceNextPayload},
    tell,
};

//
use super::*;

#[test_log::test(tokio::test)]
async fn should_fetch_then_push_then_revalidate() -> TestResult {
    //given
    let fs = given::a_filesystem();
    let (mut open_repository, repo_details) = given::an_open_repository(&fs);
    let next_commit = given::a_commit_with_message("feat: next".to_string());
    let dev_commit_history = vec![
        given::a_commit_with_message("feat: dev".to_string()),
        given::a_commit_with_message("feat: target".to_string()),
        next_commit.clone(),
    ];

    let mut seq = mockall::Sequence::new();
    open_repository
        .expect_fetch()
        .times(1)
        .in_sequence(&mut seq)
        .return_once(|| Ok(()));
    open_repository
        .expect_push()
        .times(1)
        .in_sequence(&mut seq)
        .return_once(|_, _, _, _| Ok(()));
    open_repository
        .expect_fetch()
        .times(1)
        .in_sequence(&mut seq)
        .return_once(|| Ok(()));

    //when
    let (addr, log) = when::start_actor_with_open_repository(
        Box::new(open_repository),
        repo_details,
        given::a_forge(),
    );
    tell!(
        addr,
        AdvanceNext::new(AdvanceNextPayload {
            next: next_commit.clone(),
            main: next_commit.clone(),
            dev_commit_history,
        })
    )?;
    tokio::time::sleep(Duration::from_millis(9)).await;

    //then
    tracing::debug!(?log, "");
    log.require_message_containing("send: ValidateRepo").await?;
    Ok(())
}
